/*
* 如果需要使用监控统计功能，请将PUBLIC KEY 复制到DuerOS DBP平台
* 文档参考：https://dueros.baidu.com/didp/doc/dueros-bot-platform/dbp-deploy/authentication_markdown

-----BEGIN PUBLIC KEY-----
MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDG6xc899C8Wp1A8L/txZEeEvqn
erxALIY1CRAgW7HDqrG8PHIYE3rdu0MK1YxYZDkDpACv5K6A0DEVFkNM1GEtnd4t
9v2LUXFmX8njpcKgMKk0XIVw+ltfJ2fbAkGJ3S1OdBt9Os5dNpgOdwqzSuZ1p9Vp
q7ILhyUhYI/p+Qr6sQIDAQAB
-----END PUBLIC KEY-----

*/
const Bot = require('bot-sdk');
const privateKey = require("./rsaKeys.js").privateKey;

class InquiryBot extends Bot {
    constructor(postData) {
        super(postData);

        this.addLaunchHandler(() => {
            this.waitAnswer();
            let card = new Bot.Card.StandardCard();
            card.setTitle('查询个税');
            card.setContent('欢迎使用查询个税');
            card.setImage('http://dbp-resource.gz.bcebos.com/2d304133-8784-e088-8bae-fec4b6d64e9e/home.jpg?authorization=bce-auth-v1%2Fa4d81bbd930c41e6857b989362415714%2F2018-05-23T06%3A43%3A18Z%2F-1%2F%2F98879ccd1c547f06ea71e6e4508425c8ab76efa98d1641a1c2fb8c78aee98504');
            return {
                card: card,
                outputSpeech: '欢迎使用查个税!'
            };
        });
        this.addSessionEndedHandler(() => {
            this.endSession();
            return {
                outputSpeech: '谢谢使用查个税',
            };
        });

        this.addIntentHandler('inquiry_tax', () => {
            let loc = this.getSlot('sys.city');
            let monthlySalary = this.getSlot('sys.number');
            if (!monthlySalary) {
                this.nlu.ask('sys.number');
                let card = new Bot.Card.TextCard('你工资多少');
                return Promise.resolve({
                    card: card,
                    outputSpeech: '你工资多少'
                });
            }

            if (!loc) {
                let card = new Bot.Card.TextCard('你在哪个城市');
                this.nlu.ask('sys.city');
                return {
                    card: card,
                    outputSpeech: '你在哪个城市'
                };
            }

            if (this.request.isDialogStateCompleted()) {
                let card = new Bot.Card.TextCard('你需要缴纳税款167.40元，缴纳社保及公积金1776元，税后工资是6056.60元');
                return {
                    card: card,
                    outputSpeech: '<speak>你需要缴纳税款<say-as type="number">167.40</say-as>元，缴纳社保及公积金<say-as type="number">1776</say-as>元，税后工资是<say-as type="number">6056.60</say-as>元</speak>'
                };
            }
        });
    }
}

exports.handler = function(event, context, callback) {
    try {
        let b = new InquiryBot(event);

        b.botMonitor.setEnvironmentInfo(privateKey, 0);
        b.run().then(function(result) {
            callback(null, result);
        }).catch(callback);
    } catch (e) {
        callback(e);
    }
}
